@@ -71,10 +71,9 @@ quint32 QxtGlobalShortcutPrivate::nativeModifiers(Qt::KeyboardModifiers modifier
     return native;
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 // This is only here to get it to compile on OSX
 bool QxtGlobalShortcutPrivate::nativeEventFilter(const QByteArray & eventType,
-    void * message, long * result)
+    void * message, NativeEventResult * result)
 {
     Q_UNUSED(result)
     Q_UNUSED(message)
@@ -82,8 +81,6 @@ bool QxtGlobalShortcutPrivate::nativeEventFilter(const QByteArray & eventType,
 
     return false;
 }
-#endif
-
 
 quint32 QxtGlobalShortcutPrivate::nativeKeycode(Qt::Key key, Qt::KeyboardModifiers)
 {
