@@ -1,21 +1,4 @@
-/*
-    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
-
-    This file is part of CopyQ.
-
-    CopyQ is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    CopyQ is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with CopyQ.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "textdata.h"
 
@@ -30,6 +13,8 @@
 
 namespace {
 
+const QLatin1String mimePluginPrefix(COPYQ_MIME_PREFIX "item");
+
 QString escapeHtmlSpaces(const QString &str)
 {
     QString str2 = str;
@@ -38,6 +23,13 @@ QString escapeHtmlSpaces(const QString &str)
             .replace('\n', "<br />");
 }
 
+bool isPluginFormat(const QString &mime)
+{
+    return mime.startsWith(mimePluginPrefix)
+        && mime.size() > mimePluginPrefix.size()
+        && mime[mimePluginPrefix.size()] != '-';
+}
+
 } // namespace
 
 uint hash(const QVariantMap &data)
@@ -52,6 +44,9 @@ uint hash(const QVariantMap &data)
         if (mime == mimeWindowTitle || mime == mimeOwner || mime == mimeClipboardMode)
             continue;
 
+        if ( isPluginFormat(mime) )
+            continue;
+
         seed = hash(seed, mime);
         seed = hash(seed, data[mime].toByteArray());
     }
