@@ -1,21 +1,4 @@
-/*
-    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
-
-    This file is part of CopyQ.
-
-    CopyQ is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    CopyQ is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with CopyQ.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef CLIPBOARDBROWSER_H
 #define CLIPBOARDBROWSER_H
@@ -39,6 +22,7 @@
 class ItemEditorWidget;
 class ItemFactory;
 class PersistentDisplayItem;
+class QPersistentModelIndex;
 class QProgressBar;
 class QPushButton;
 
@@ -65,6 +49,7 @@ class ClipboardBrowser final : public QListView
 
         /** Sort selected items. */
         void sortItems(const QModelIndexList &indexes);
+        void sortItems(const QList<QPersistentModelIndex> &sorted);
 
         /** Reverse order of selected items. */
         void reverseItems(const QModelIndexList &indexes);
