@@ -1,21 +1,4 @@
-/*
-    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
-
-    This file is part of CopyQ.
-
-    CopyQ is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    CopyQ is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with CopyQ.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "scriptableproxy.h"
 
@@ -1991,6 +1974,28 @@ void ScriptableProxy::selectionMove(int id, int row)
         selection.browser->move(indexes, row);
 }
 
+void ScriptableProxy::selectionSort(int id, const QVector<int> &indexes)
+{
+    INVOKE2(selectionSort, (id, indexes));
+
+    auto selection = m_selections.value(id);
+
+    QList<QPersistentModelIndex> sorted;
+    sorted.reserve( indexes.size() );
+    for (const int i : indexes) {
+        if (i < 0 || i >= selection.indexes.size())
+            continue;
+
+        const auto index = selection.indexes[i];
+        if ( index.isValid() )
+            sorted.append(index);
+    }
+    selection.indexes = sorted;
+
+    if ( !sorted.isEmpty() )
+        selection.browser->sortItems(sorted);
+}
+
 #ifdef HAS_TESTS
 void ScriptableProxy::sendKeys(const QString &expectedWidgetName, const QString &keys, int delay)
 {
