@@ -1,21 +1,4 @@
-/*
-    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
-
-    This file is part of CopyQ.
-
-    CopyQ is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    CopyQ is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with CopyQ.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef SCRIPTABLEPROXY_H
 #define SCRIPTABLEPROXY_H
@@ -218,6 +201,7 @@ public slots:
     QVariantList selectionGetItemsFormat(int id, const QString &format);
     void selectionSetItemsFormat(int id, const QString &mime, const QVariant &value);
     void selectionMove(int id, int row);
+    void selectionSort(int id, const QVector<int> &indexes);
 
 #ifdef HAS_TESTS
     void sendKeys(const QString &expectedWidgetName, const QString &keys, int delay);
