@@ -1,21 +1,4 @@
-/*
-    Copyright (c) 2020, Lukas Holecek <hluk@email.cz>
-
-    This file is part of CopyQ.
-
-    CopyQ is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    CopyQ is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with CopyQ.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef TESTS_H
 #define TESTS_H
@@ -156,6 +139,7 @@ private slots:
     void classItemSelection();
     void classItemSelectionGetCurrent();
     void classItemSelectionByteArray();
+    void classItemSelectionSort();
     void classSettings();
     void calledWithInstance();
 
@@ -176,6 +160,7 @@ private slots:
     void searchRowNumber();
     void searchAccented();
     void copyItems();
+    void selectAndCopyOrder();
 
     void createTabDialog();
 
