@@ -3,9 +3,8 @@ set -e
 
 distros=(
     focal
-    hirsute
-    impish
     jammy
+    kinetic
 )
 
 sed -i 's/quilt/native/' 'debian/source/format'
